Maskable

Derive Macro Maskable 

#[derive(Maskable)]
{
    // Attributes available to this derive:
    #[fieldmask]
}
Derive Maskable for the type.

The type must be one of the following types:

  • A unit-like enum.
  • An enum where each variant has exactly one unnamed associated field. The associated field must implement Maskable.
  • A struct with named fields, where the type of each field must implement Maskable.